# Desktop Crashes

Generate a view that unions different sources for Firefox desktop crash pings.
Schemas for the different tables should be equivalent but fields may be in different order or 
with removed metrics missing from newer tables.
If fields do not match, the output will be a union of all the fields.
